@@ -3,20 +3,20 @@
 #include "../krusader.h"
 #include <tqpixmap.h>
 #include <kiconloader.h>
-#include <kaction.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdeaction.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kdebug.h>
 
 KrBookmarkButton::KrBookmarkButton(TQWidget *parent): TQToolButton(parent) {
-	TQPixmap icon = krLoader->loadIcon("bookmark", KIcon::Toolbar, 16);
+	TQPixmap icon = krLoader->loadIcon("bookmark", TDEIcon::Toolbar, 16);
 	setFixedSize(icon.width() + 4, icon.height() + 4);
 	setPixmap(icon);
 	setTextLabel(i18n("BookMan II"), true);
 	setPopupDelay(10); // 0.01 seconds press
 	setAcceptDrops(false);
 
-	acmBookmarks = new KActionMenu(i18n("Bookmarks"), "bookmark", 0, 0);
+	acmBookmarks = new TDEActionMenu(i18n("Bookmarks"), "bookmark", 0, 0);
 	acmBookmarks->setDelayed(false);
 	acmBookmarks->popupMenu()->setKeyboardShortcutsEnabled(true);
 	acmBookmarks->popupMenu()->setKeyboardShortcutsExecute(true);
@@ -27,7 +27,7 @@ KrBookmarkButton::KrBookmarkButton(TQWidget *parent): TQToolButton(parent) {
 }
 
 void KrBookmarkButton::populate() {
-	krBookMan->populate(static_cast<KPopupMenu*>(popup()));
+	krBookMan->populate(static_cast<TDEPopupMenu*>(popup()));
 }
 
 void KrBookmarkButton::openPopup() {
