@@ -38,7 +38,7 @@
 
 class FilterTabs : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
