@@ -49,7 +49,7 @@
 class KCMDModeButton;
 
 class KrHistoryCombo: public KHistoryCombo {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
@@ -63,7 +63,7 @@ class KrHistoryCombo: public KHistoryCombo {
 };
 
 class KCMDLine : public TQWidget, KrActionBase {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     KCMDLine( TQWidget *parent = 0, const char *name = 0 );
