@@ -52,7 +52,7 @@ class KrView;
    a different thread.
  */
 class KrCalcSpaceDialog : public KDialogBase{
-	Q_OBJECT
+	TQ_OBJECT
   
 	/* Thread which does the actual calculation. Deletes itself, if no longer
 	   needed. Creator must call finished(), if the thread is no longer needed.
